/******************************************************************************
  MotorTest.ino
  Serial Controlled Motor Driver
  Marshall Taylor @ SparkFun Electronics
  Sept 15, 2016
  https://github.com/sparkfun/Serial_Controlled_Motor_Driver
  https://github.com/sparkfun/SparkFun_Serial_Controlled_Motor_Driver_Arduino_Library

  Resources:
  Uses Wire.h for i2c operation
  Uses SPI.h for SPI operation

  Development environment specifics:
  Arduino IDE 1.6.7
  Teensy loader 1.27

  This code is released under the [MIT License](http://opensource.org/licenses/MIT).
  Please review the LICENSE.md file included with this example. If you have any questions
  or concerns with licensing, please contact techsupport@sparkfun.com.
  Distributed as-is; no warranty is given.
******************************************************************************/
//This example steps through all motor positions moving them forward, then backwards.
//To use, connect a redboard to the user port, as many slaves as desired on the expansion
//port, and run the sketch.
//
// Notes:
//    While using SPI, the defualt LEDPIN will not toggle
//    This steps through all 34 motor positions, which takes a few seconds to loop.

#include <Arduino.h>
#include <stdint.h>
#include "SCMD.h"
#include "SCMD_config.h" //Contains #defines for common SCMD register names and values
#include "Wire.h"

#define LEDPIN 13

SCMD myMotorDriver; //This creates the main object of one motor driver and connected slaves.

void setup()
{
  Serial.begin(9600);
  pinMode(LEDPIN, OUTPUT);

  Serial.println("Starting sketch.");

  //***** Configure the Motor Driver's Settings *****//
  //  .commInter face can be I2C_MODE or SPI_MODE
  myMotorDriver.settings.commInterface = I2C_MODE;
  //myMotorDriver.settings.commInterface = SPI_MODE;

  //  set address if I2C configuration selected with the config jumpers
  myMotorDriver.settings.I2CAddress = 0x5D; //config pattern "0101" on board for address 0x5A

  //  set chip select if SPI selected with the config jumpers
  myMotorDriver.settings.chipSelectPin = 10;

  //*****initialize the driver get wait for idle*****//
  while ( myMotorDriver.begin() != 0xA9 ) //Wait until a valid ID word is returned
  {
    Serial.println( "ID mismatch, trying again" );
    delay(500);
  }
  Serial.println( "ID matches 0xA9" );

  //  Check to make sure the driver is done looking for slaves before beginning
  Serial.print("Waiting for enumeration...");
  while ( myMotorDriver.ready() == false );
  Serial.println("Done.");
  Serial.println();

  //*****Set application settings and enable driver*****//

  while ( myMotorDriver.busy() );
  myMotorDriver.enable();

  Serial.println();

}

void loop()
{
  int wheel_vel;  //linear velocity of the robot
  int left_vel;   //left wheel velocity
  int right_vel;  //right wheel velocity
  float cal_factor; //calibration factor
  //***** Operate the Motor Driver *****//
  //  This walks through all 34 motor positions driving them forward and back.
  //  It uses .setDrive( motorNum, direction, level ) to drive the motors.

  Serial.println("Now stepping through the motors.");

  digitalWrite( LEDPIN, 0 );
  digitalWrite( LEDPIN, 1 );
  wheel_vel = 0;
  myMotorDriver.setDrive( 0, 0, wheel_vel); //Drive motor 0 - Left wheel
  myMotorDriver.setDrive( 1, 1, wheel_vel); //Drive motor 1 - Right wheel
  delay(15000);

  cal_factor = (float)52.0/60.0;
  wheel_vel = 140;
  right_vel = wheel_vel;
  left_vel = cal_factor*wheel_vel;
  
  //go straight
  myMotorDriver.setDrive( 0, 0, left_vel); //Drive motor 0 - Left wheel
  myMotorDriver.setDrive( 1, 1, right_vel); //Drive motor 1 - Right wheel
  delay(500);
  
  //turn 90 degrees
  myMotorDriver.setDrive( 0, 1, left_vel); //Drive motor 0 - Left wheel
  myMotorDriver.setDrive( 1, 1, right_vel); //Drive motor 1 - Right wheel
  delay(250);

  //go straight
  myMotorDriver.setDrive( 0, 0, left_vel); //Drive motor 0 - Left wheel
  myMotorDriver.setDrive( 1, 1, right_vel); //Drive motor 1 - Right wheel
  delay(500);

  //turn 90 degrees
  myMotorDriver.setDrive( 0, 1, left_vel); //Drive motor 0 - Left wheel
  myMotorDriver.setDrive( 1, 1, right_vel); //Drive motor 1 - Right wheel
  delay(250);

  //go straight
  myMotorDriver.setDrive( 0, 0, left_vel); //Drive motor 0 - Left wheel
  myMotorDriver.setDrive( 1, 1, right_vel); //Drive motor 1 - Right wheel
  delay(500);

  //turn 90 degrees
  myMotorDriver.setDrive( 0, 1, left_vel); //Drive motor 0 - Left wheel
  myMotorDriver.setDrive( 1, 1, right_vel); //Drive motor 1 - Right wheel
  delay(250);

  //go straight
  myMotorDriver.setDrive( 0, 0, left_vel); //Drive motor 0 - Left wheel
  myMotorDriver.setDrive( 1, 1, right_vel); //Drive motor 1 - Right wheel
  delay(500);

  //stop
  wheel_vel = 0;
  right_vel = wheel_vel;
  left_vel = cal_factor*wheel_vel;
  myMotorDriver.setDrive( 0, 0, left_vel); //Drive motor 0 - Left wheel
  myMotorDriver.setDrive( 1, 1, right_vel); //Drive motor 1 - Right wheel
  delay(10000);

  

}
